@@ -19,7 +19,7 @@ use Perinci::CmdLine::Gen qw(gen_pericmd_script);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-10-30'; # DATE
 our $DIST = 'Test-Perinci-CmdLine'; # DIST
-our $VERSION = '1.482'; # VERSION
+our $VERSION = '1.483'; # VERSION
 
 our @EXPORT = (
     'pericmd_ok', # old, back-compat
@@ -304,7 +304,7 @@ sub pericmd_run_test_groups_ok {
             if ($exclude_tags) {
                 for my $tag (@$tags) {
                     if (grep { $_ eq $tag } @$exclude_tags) {
-                        plan skip_all => "Has one of the exclude_tag: $_";
+                        plan skip_all => "Has one of the exclude_tag: $tag";
                         return;
                     }
                 }
@@ -1810,7 +1810,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.482 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2023-10-30.
+This document describes version 1.483 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2023-10-30.
 
 =for Pod::Coverage ^(pericmd_ok)$
 
